# Chromatin

This **neovim** python remote plugin provides management for plugins built with [ribosome] and distributed over
**pypi**.

This is the python package that will be autoinstalled by the separate [neovim plugin stub][chromatin.nvim].

For installation and usage instructions, consult the readme of the plugin.

[ribosome]: https://github.com/tek/ribosome
[chromatin.nvim]: https://github.com/tek/chromatin.nvim
